summaryrefslogtreecommitdiff
path: root/sw/source/core/access/accframe.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/core/access/accframe.cxx')
-rw-r--r--sw/source/core/access/accframe.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/sw/source/core/access/accframe.cxx b/sw/source/core/access/accframe.cxx
index a62afc11e551..f6778c1564b8 100644
--- a/sw/source/core/access/accframe.cxx
+++ b/sw/source/core/access/accframe.cxx
@@ -438,7 +438,7 @@ const SwFrm *SwAccessibleFrame::GetParent( const SwFrmOrObj& rFrmOrObj,
const SwFlyFrm *pFly = static_cast< const SwFlyFrm *>( pFrm );
if( pFly->IsFlyInCntFrm() )
{
// For FLY_IN_CNTNT the parent is the anchor
aParent = pFly->GetAnchorFrm();
ASSERT( aParent.IsAccessible( bInPagePreview ),
"parent is not accessible" );
@@ -471,9 +471,9 @@ const SwFrm *SwAccessibleFrame::GetParent( const SwFrmOrObj& rFrmOrObj,
{
const SwFrmFmt *pFrmFmt = pContact->GetFmt();
ASSERT( pFrmFmt, "frame format is missing" );
- if( pFrmFmt && FLY_IN_CNTNT == pFrmFmt->GetAnchor().GetAnchorId() )
+ if (pFrmFmt && FLY_AS_CHAR == pFrmFmt->GetAnchor().GetAnchorId())
{
// For FLY_IN_CNTNT the parent is the anchor
aParent = pContact->GetAnchorFrm();
ASSERT( aParent.IsAccessible( bInPagePreview ),
"parent is not accessible" );
@@ -438,7 +438,7 @@ const SwFrm *SwAccessibleFrame::GetParent( const SwFrmOrObj& rFrmOrObj,
if( pFly->IsFlyInCntFrm() )
{
- // For FLY_IN_CNTNT the parent is the anchor
+ // For FLY_AS_CHAR the parent is the anchor
aParent = pFly->GetAnchorFrm();
ASSERT( aParent.IsAccessible( bInPagePreview ),
@@ -471,9 +471,9 @@ const SwFrm *SwAccessibleFrame::GetParent( const SwFrmOrObj& rFrmOrObj,
{
- // For FLY_IN_CNTNT the parent is the anchor
+ // For FLY_AS_CHAR the parent is the anchor
aParent = pContact->GetAnchorFrm();
ASSERT( aParent.IsAccessible( bInPagePreview ),